#include "gpipe.ih"

GPipe::~GPipe()
{
    close();
}
